<?php

/**
 * @file Including Helper functions.
 * @author: mosama
 */

/**
 * get current user picture
 */
function get_user_picture() {
  global $user;
  if (isset($user->picture) && $user->picture != 0) {
    $user_item = user_load($user->uid);
    $user_pic = theme('user_picture', array('account' => $user_item));
  }
  else {
    $user_pic = "<img src='" . base_path() . drupal_get_path('theme', 'time_tracking') . "/images/default_user_pic.png' />";
  }
  return $user_pic;
}

/**
 * List all site users
 */
function get_users_data() {
  $query = db_select('users', 'u');
  $query->leftJoin('field_data_field_user_group', 'g', 'g.entity_id = u.uid');
  $query->leftJoin('field_data_field_user_full_name', 'f', 'f.entity_id = u.uid');
  $result = $query->fields('u', array('name', 'uid'))
      ->fields('g', array('field_user_group_value'))
      ->fields('f', array('field_user_full_name_value'))
      ->condition('u.uid', array(0, 1, 2), 'NOT IN')
      ->execute()
      ->fetchAll();

  $users = array();
  foreach ($result as $key => $value) {
    $user = new stdClass();
    $user->uid = $value->uid;
    $user->name = $value->name;
    $user->group = (isset($value->field_user_group_value) ? $value->field_user_group_value : 'no');
    $user->full_name = (isset($value->field_user_full_name_value) ? $value->field_user_full_name_value : $user->name);
    $users[] = $user;
  }

  return $users;
}

/**
 * Calculate range between two dates.
 * @param date $strDateFrom
 * @param date $strDateTo
 * @return date
 */
function createDateRange($strDateFrom, $strDateTo) {
  $aryRange = array();
  $iDateFrom = mktime(1, 0, 0, substr($strDateFrom, 5, 2), substr($strDateFrom, 8, 2), substr($strDateFrom, 0, 4));
  $iDateTo = mktime(1, 0, 0, substr($strDateTo, 5, 2), substr($strDateTo, 8, 2), substr($strDateTo, 0, 4));
  if ($iDateTo >= $iDateFrom) {
    array_push($aryRange, date('Y-m-d', $iDateFrom)); // first entry
    while ($iDateFrom < $iDateTo) {
      $iDateFrom+=86400; // add 24 hours
      array_push($aryRange, date('Y-m-d', $iDateFrom));
    }
  }
  return $aryRange;
}

/**
 * get vacatiobs dates by uid
 * @param type $uid
 * @return type
 */
function get_dates_by_uid($uid) {
  $query = db_select('field_data_field_absence_day', 'd');
  $query->join('field_data_field_absence_user_id', 'u', 'd.entity_id = u.entity_id');
  $result = $query->fields('d', array('field_absence_day_value'))
      ->condition('u.field_absence_user_id_value', $uid)
      ->execute()
      ->fetchAll();
  return $result;
}

/**
 * get user groub from uid
 * @param type $uid
 */
function get_group_by_uid($uid) {
  return db_select('field_data_field_user_group', 'g')->fields('g', array('field_user_group_value'))->condition('entity_id', $uid)->execute()->fetchField();
}

/**
 * get user name by uid
 * @param type $uid
 * @return type
 */
function get_name_by_uid($uid) {
  return db_select('users', 'u')->fields('u', array('name'))->condition('uid', $uid)->execute()->fetchField();
}

/**
 * get full name by uid
 * @param type $uid
 * @return type
 */
function get_full_name_by_uid($uid) {
  return db_select('field_data_field_user_full_name', 'u')->fields('u', array('field_user_full_name_value'))->condition('entity_id', $uid)->execute()->fetchField();
}

/**
 * Get current user upcoming vacation
 * @global type $user
 * @return type
 */
function your_upcoming_vacation() {
  global $user;
  $today = date('Y-m-d 00:00:00');

  $query = db_select('field_data_field_absence_day', 'd');
  $query->join('field_data_field_absence_user_id', 'i', 'i.entity_id = d.entity_id');
  $query->join('field_data_field_absence_type', 't', 't.entity_id = i.entity_id');
  $result = $query->fields('d', array('field_absence_day_value'))
      ->orderBy('d.field_absence_day_value', 'ASC')
      ->condition('i.field_absence_user_id_value', $user->uid)
      ->condition('d.field_absence_day_value', $today, '>')
      ->condition('t.field_absence_type_value', 'request', '!=')
      ->execute()
      ->fetchField();

  return $result;
}

/**
 * Chaeck if the date is today or tomorrow and return date in string
 * @param date $date
 */
function check_if_today_tomorrow($date_to_Check) {

  $output_date = $date_to_Check;
  $date = date('Y-m-d', strtotime($date_to_Check));
  $today = date('Y-m-d');
  $tomorrow = date('Y-m-d', strtotime('tomorrow'));
  if ($date == $today) {
    $output_date = "<b>Today</b>";
  }
  else if ($date == $tomorrow) {
    $output_date = "<b>Tomorrow</b>";
  }

  return $output_date;
}
